aboutsummaryrefslogtreecommitdiffstats
path: root/g10/armor.c
diff options
context:
space:
mode:
authorWerner Koch <[email protected]>1998-11-18 19:59:06 +0000
committerWerner Koch <[email protected]>1998-11-18 19:59:06 +0000
commitf9d2bd8cb957c857098dcf90b48f7b62afdbca1b (patch)
tree972498d252b949db7107a319270d853178c5d531 /g10/armor.c
parentSpanish laguage support (es_ES) (diff)
downloadgnupg-f9d2bd8cb957c857098dcf90b48f7b62afdbca1b.tar.gz
gnupg-f9d2bd8cb957c857098dcf90b48f7b62afdbca1b.zip
some bug fixes
Diffstat (limited to 'g10/armor.c')
-rw-r--r--g10/armor.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/g10/armor.c b/g10/armor.c
index 46c3cc62d..c1da9accd 100644
--- a/g10/armor.c
+++ b/g10/armor.c
@@ -1,14 +1,14 @@
/* armor.c - Armor filter
* Copyright (C) 1998 Free Software Foundation, Inc.
*
* This file is part of GNUPG.
*
* GNUPG is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* GNUPG is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
@@ -1008,7 +1008,7 @@ armor_filter( void *opaque, int control,
iobuf_writestr(a, "-----");
iobuf_writestr(a, head_strings[afx->what] );
iobuf_writestr(a, "-----\n");
- iobuf_writestr(a, "Version: GNUPG v" VERSION " ("
+ iobuf_writestr(a, "Version: GnuPG v" VERSION " ("
PRINTABLE_OS_NAME ")\n");
if( opt.comment_string ) {
@@ -1,14 +1,14 @@
* Copyright (C) 1998 Free Software Foundation, Inc.
*
- * This file is part of GNUPG.
+ * This file is part of GnuPG.
*
@@ -1,14 +1,14 @@
*
- * GNUPG is free software; you can redistribute it and/or modify
+ * GnuPG is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,14 +1,14 @@
* (at your option) any later version.
*
- * GNUPG is distributed in the hope that it will be useful,
+ * GnuPG is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the